Stan Math Library: stan/math/prim/mat/prob/matrix_normal_prec_log.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
matrix_normal_prec_log.hpp File Reference
`#include <stan/math/prim/mat/err/check_ldlt_factor.hpp>`
`#include <stan/math/prim/scal/err/check_size_match.hpp>`
`#include <stan/math/prim/mat/err/check_symmetric.hpp>`
`#include <stan/math/prim/scal/err/check_finite.hpp>`
`#include <stan/math/prim/scal/err/check_not_nan.hpp>`
`#include <stan/math/prim/scal/err/check_positive.hpp>`
`#include <stan/math/prim/mat/fun/log.hpp>`
`#include <stan/math/prim/mat/fun/log_determinant.hpp>`
`#include <stan/math/prim/mat/fun/log_determinant_ldlt.hpp>`
`#include <stan/math/prim/mat/fun/subtract.hpp>`
`#include <stan/math/prim/mat/fun/trace_quad_form.hpp>`
`#include <stan/math/prim/mat/fun/trace_gen_quad_form.hpp>`
`#include <stan/math/prim/scal/fun/constants.hpp>`
`#include <stan/math/prim/scal/meta/include_summand.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<bool propto, typename T_y , typename T_Mu , typename T_Sigma , typename T_D >
boost::math::tools::promote_args< T_y, T_Mu, T_Sigma, T_D >::type | stan::math::matrix_normal_prec_log (const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &y, const Eigen::Matrix< T_Mu, Eigen::Dynamic, Eigen::Dynamic > &Mu, const Eigen::Matrix< T_Sigma, Eigen::Dynamic, Eigen::Dynamic > &Sigma, const Eigen::Matrix< T_D, Eigen::Dynamic, Eigen::Dynamic > &D)
| The log of the matrix normal density for the given y, mu, Sigma and D where Sigma and D are given as precision matrices, not covariance matrices. More...
template<typename T_y , typename T_Mu , typename T_Sigma , typename T_D >
boost::math::tools::promote_args< T_y, T_Mu, T_Sigma, T_D >::type | stan::math::matrix_normal_prec_log (const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &y, const Eigen::Matrix< T_Mu, Eigen::Dynamic, Eigen::Dynamic > &Mu, const Eigen::Matrix< T_Sigma, Eigen::Dynamic, Eigen::Dynamic > &Sigma, const Eigen::Matrix< T_D, Eigen::Dynamic, Eigen::Dynamic > &D)

[ Stan Home Page ] © 2011–2016, Stan Development Team.